#!/bin/bash

BUILD="17A405"

PKG_SRC="https://images.nvidia.com/mac/pkg/378/WebDriver-378.10.10.10.15.120.pkg"

if [ "$(id -u)" != "0" ]; then
	 printf "Run it as root:\n\n"
   printf "sudo $0\n\n"
   exit 1
fi

sw_vers | grep $BUILD > /dev/null 2>&1

if [ $? -eq 0 ]
	
then

	printf "\nAlternative Installer for WebDriver-378.10.10.10.15.120\n\n"

	# Uninstall
	
	rm -rf ~/.nvwebinstall > /dev/null 2>&1
	rm -f ~/.nvweb.pkg > /dev/null 2>&1
	rm -f ~/.nvweb.sql > /dev/null 2>&1

	rm -rf /Library/Extensions/GeForce* > /dev/null 2>&1
	rm -rf /Library/Extensions/NVDA* > /dev/null 2>&1
	rm -rf /System/Library/Extensions/GeForce*Web* > /dev/null 2>&1
	rm -rf /System/Library/Extensions/NVDA*Web* > /dev/null 2>&1

	# Download

	printf "Downloading package...\n"
	curl -o ~/.nvweb.pkg $PKG_SRC

	# Extract
	
	printf "Extracting...\n"
	pkgutil --expand ~/.nvweb.pkg ~/.nvwebinstall
	cd ~/.nvwebinstall/*NVWebDrivers.pkg
	cat Payload | gunzip -dc | cpio -i

	# Make SQL

	printf "Approving kexts...\n"
	TEAM_ID="6KR3T733EC"
	BUNDLE_IDS=(com.nvidia.CUDA com.nvidia.web.GeForceTeslaWeb com.nvidia.web.GeForceWeb com.nvidia.web.NVDAGF100HalWeb com.nvidia.web.NVDAGK100HalWeb com.nvidia.web.NVDAGM100HalWeb com.nvidia.web.NVDAGP100HalWeb com.nvidia.web.NVDANV50HalTeslaWeb com.nvidia.web.NVDAResmanTeslaWeb com.nvidia.web.NVDAResmanWeb com.nvidia.NVDAStartupWeb)
	DEVELOPER_NAME="NVIDIA Corporation"
	for BUNDLE in "${BUNDLE_IDS[@]}"
	do
		printf "insert or replace into kext_policy (team_id, bundle_id, allowed, developer_name, flags) values (\"$TEAM_ID\",\"$BUNDLE\",1,\"$DEVELOPER_NAME\",1);\n" >> ~/.nvweb.sql
	done

	# Allow kexts

	/usr/bin/sqlite3 /var/db/SystemPolicyConfiguration/KextPolicy < ~/.nvweb.sql

	# Install

	printf "Installing...\n"
	cp -r ./Library/Extensions/* /Library/Extensions
	cp -r ./System/Library/Extensions/* /System/Library/Extensions

	# Update caches

	printf "Updating caches...\n"
	touch /Library/Extensions /System/Library/Extensions
	kextcache -u /

	# Clean up

	rm -rf ~/.nvwebinstall
	rm -f ~/.nvweb.pkg
	rm -f ~/.nvweb.sql
	
	printf "Complete.\n"
	printf "\n\nYou should reboot now.\n\n"

else
	
	printf "\nOS build version isn't $BUILD, exitting\n\n"
	exit 1	
	
fi
